@@ -175,7 +175,14 @@ class Lotus:
         # Main loop
         self.order = BitmexOrder(self.symbols,
                                  self.client, self.settings, self._settings_path)     
-        self.process_signals(self.get_api_signal(), start=True)
+        while True:
+            signal = self.get_api_signal()
+            if not signal:
+                print("Trying again in 1 Minute.", flush=True)
+                time.sleep(60)
+            else:
+                self.process_signals(signal, start=True)
+                break
         while True:
             time.sleep(10)
             self.order.manage_entries(self.symbols)
@@ -185,7 +192,9 @@ class Lotus:
                 count_s_tries = 0
                 while True:
                     signal = self.get_api_signal()
-                    if self.is_new_signal(signal):
+                    if not signal:
+                        break
+                    elif self.is_new_signal(signal):
                         # make sure to get the signal
                         self.process_signals(signal)
                         break
